@@ -5,15 +5,18 @@ Created on 5 avr. 2010
 @author: thierry
 '''
 
+import storage
+
 from caritang.common import version 
 
-version.getInstance().submitRevision("$Revision: 2 $")
+version.getInstance().submitRevision("$Revision: 24 $")
 
 class Archiver(object):
     '''
     This class is responsible for upload documents to google docs account.
     '''
-
+    
+    
 
     def __init__(self):
         '''
@@ -21,6 +24,7 @@ class Archiver(object):
         '''
         self.sources = []
         self.storages = []
+        self.progress_listener = None
             
     
     def addSource(self, aSource):
@@ -34,8 +38,12 @@ class Archiver(object):
         save all source data to each storage. The default parameter resume is valued
         to True so the archiver attemps to resume the backup e.g. backup only new file.
         '''
-        for source in self.sources :
-            for doc in source.list_document() :
-                for storage in self.storages :
-                    storage.store(doc)
+        for a_source in self.sources :
+            for doc in a_source.list_document() :
+                for a_storage in self.storages :
+                    try :
+                        a_storage.store(doc)
+                    except storage.CaritangStorageException, e:
+                        if self.progress_listener is not None:
+                            self.progress_listener.receive_signal(e)
                     
\ No newline at end of file
