@@ -9,15 +9,24 @@ import os.path
 
 from caritang.common import version 
 
-version.getInstance().submitRevision("$Revision: 2 $")
+version.getInstance().submitRevision("$Revision: 26 $")
 
 
 NOT_YET_IMPLEMENTED = "not yet implemented"
 
 class DocSource(object):
     '''
-    Interace for any document source
+    Interace for any document source. A document source may content many elements.
     '''
+
+class DocItem(object):
+    '''
+    Interface for a document item
+    '''
+    
+    def getName(self):
+        pass
+    
     
 
 class Directory(DocSource):
@@ -37,7 +46,7 @@ class Directory(DocSource):
     def list_document(self):
         for root, dirs, files in os.walk(self.directory) :
             if not self.recursive:
-                dirs.clear()
+                del dirs[:]
             for file in files :
                 yield os.path.join(root, file)
 
